@@ -3,17 +3,13 @@ package Memoize::Expire;
 # require 5.00556;
 use Carp;
 use vars qw($DEBUG);
-$VERSION = '1.06';
+$VERSION = '1.07';
 
-# This package will implement expiration by prepending a fixed-length header
-# to the font of the cached data.  The format of the header will be:
+# The format of the metadata is:
 # (4-byte number of last-access-time)  (For LRU when I implement it)
 # (4-byte expiration time: unsigned seconds-since-unix-epoch)
 # (2-byte number-of-uses-before-expire)
 
-sub _header_fmt () { "N N n" }
-sub _header_size () { length(_header_fmt) }
-
 # Usage:  memoize func 
 #         TIE => [Memoize::Expire, LIFETIME => sec, NUM_USES => n,
 #                 TIE => [...] ]
@@ -54,27 +50,25 @@ sub STORE {
   # The call that results in a value to store into the cache is the
   # first of the NUM_USES allowed calls.
   my $header = _make_header(time, $expire_time, $self->{NUM_USES}-1);
-  $self->{C}{$key} = $header . $value;
+  @{$self->{C}}{"H$key", "V$key"} = ($header, $value);
   $value;
 }
 
 sub FETCH {
   $DEBUG and print STDERR " >> Fetch cached value for $_[1]\n";
-  my ($data, $last_access, $expire_time, $num_uses_left) = _get_item($_[0]{C}{$_[1]});
+  my ($last_access, $expire_time, $num_uses_left) = _get_header($_[0]{C}{"H$_[1]"});
   $DEBUG and print STDERR " >>   (ttl: ", ($expire_time-time()), ", nuses: $num_uses_left)\n";
-  $num_uses_left--;
-  $last_access = time;
-  _set_header(@_, $data, $last_access, $expire_time, $num_uses_left);
-  $data;
+  $_[0]{C}{"H$_[1]"} = _make_header(time, $expire_time, --$num_uses_left);
+  $_[0]{C}{"V$_[1]"};
 }
 
 sub EXISTS {
   $DEBUG and print STDERR " >> Exists $_[1]\n";
-  unless (exists $_[0]{C}{$_[1]}) {
+  unless (exists $_[0]{C}{"V$_[1]"}) {
     $DEBUG and print STDERR "    Not in underlying hash at all.\n";
     return 0;
   }
-  my $item = $_[0]{C}{$_[1]};
+  my $item = $_[0]{C}{"H$_[1]"};
   my ($last_access, $expire_time, $num_uses_left) = _get_header($item);
   my $ttl = $expire_time - time;
   if ($DEBUG) {
@@ -91,28 +85,23 @@ sub EXISTS {
   }
 }
 
+sub FIRSTKEY {
+  scalar keys %{$_[0]{C}};
+  &NEXTKEY;
+}
+
+sub NEXTKEY {
+  while (defined(my $key = each %{$_[0]{C}})) {
+    return substr $key, 1 if 'V' eq substr $key, 0, 1;
+  }
+  undef;
+}
+
 # Arguments: last access time, expire time, number of uses remaining
 sub _make_header {
   pack "N N n", @_;
 }
 
-sub _strip_header {
-  substr($_[0], 10);
-}
-
-# Arguments: last access time, expire time, number of uses remaining
-sub _set_header {
-  my ($self, $key, $data, @header) = @_;
-  $self->{C}{$key} = _make_header(@header) . $data;
-}
-
-sub _get_item {
-  my $data = substr($_[0], 10);
-  my @header = unpack "N N n", substr($_[0], 0, 10);
-#  print STDERR " >> _get_item: $data => $data @header\n";
-  ($data, @header);
-}
-
 # Return last access time, expire time, number of uses remaining
 sub _get_header  {
   unpack "N N n", substr($_[0], 0, 10);
